==> paykunpay-lib-1.0-sources.jar: paykunpay/yashoka/com/paykunpay_lib/PaykunApiCall.java <==
package paykunpay.yashoka.com.paykunpay_lib;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Intent;
import android.util.Log;
import android.webkit.WebView;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.VolleyLog;
import com.android.volley.toolbox.JsonObjectRequest;

import org.json.JSONException;
import org.json.JSONObject;

import static paykunpay.yashoka.com.paykunpay_lib.AppController.TAG;


public class PaykunApiCall {

    private String urlJsonObj = "https://checkout.paykun.com/test/order/create";
    private ProgressDialog pDialog;

    public PaykunApiCall() {
    }

    public  void callApi(Activity activity, String name, String phone){
        Log.e(""," value from project : "+name+" : "+phone);
        //Intent i = new Intent(activity,MainActivity.class);

        Toast.makeText(activity,": api call ",Toast.LENGTH_SHORT).show();
        WebView webView = new WebView(activity);
        webView.loadUrl("wwww.google.com");

        pDialog = new ProgressDialog(activity);
        pDialog.setMessage("Please wait...");
        pDialog.setCancelable(false);

        makeJsonObjectRequest(activity);


    }
    private void makeJsonObjectRequest(final Activity activity) {

        showpDialog();
        JSONObject object = new JSONObject();
        try {
            object.put("merchant_id","201805020001");
            object.put("access_token","asdjfjsdaklfsajf");
            object.put("customer_name","Prashant");
            object.put("customer_email","kambadprashant@gmail.com");
            object.put("customer_phone","9974740564");
            object.put("product_name","Yasoka Product");
            object.put("order_no","789581254");
            object.put("amount","20");
            object.put("device_id","device_id");
            object.put("imei_no","1235644897645");

            object.put("package_name","com.tesdc.test");
            object.put("device_token","aasdfjlkasdfjalksrioewrjlkdsjflsdajf");
            object.put("client_ip","127.0.0.1");
            object.put("os_name","android");
            object.put("os_version","8");

            object.put("timestamp","1552545854");
            object.put("signature","alksdjflasdjflkjasjhasjkasdgfkjashkhjsadhfjsdjfnjsjerhiuisufwrieigbakbbbakjghsdkfhjsddfkasdjffbaskjdfbfdsk");
        } catch (JSONException e) {
            e.printStackTrace();
        }
        JsonObjectRequest jsonObjReq = new JsonObjectRequest(Request.Method.POST,
                urlJsonObj, object, new Response.Listener<JSONObject>() {

            @Override
            public void onResponse(JSONObject response) {
                Log.e(" response : ", response.toString());

                WebView webView = new WebView(activity);
                webView.getSettings().setJavaScriptEnabled(true);
                webView.loadUrl("http://www.google.com");

                try {
                    // Parsing json object response
                    // response will be a json object
                } catch (Exception  e) {
                    e.printStackTrace();
                    Toast.makeText(activity, "Error: " + e.getMessage(), Toast.LENGTH_LONG).show();
                }
                hidepDialog();
            }
        }, new Response.ErrorListener() {

            @Override
            public void onErrorResponse(VolleyError error) {
                VolleyLog.d(TAG, "Error: " + error.getMessage());
                Toast.makeText(activity,
                        error.getMessage(), Toast.LENGTH_SHORT).show();
                // hide the progress dialog
                hidepDialog();
            }
        });

        // Adding request to request queue
        AppController.getInstance().addToRequestQueue(jsonObjReq);
    }
    private void showpDialog() {
        if (!pDialog.isShowing())
            pDialog.show();
    }

    private void hidepDialog() {
        if (pDialog.isShowing())
            pDialog.dismiss();
    }
}

==> paykunpay-lib-1.1.3-sources.jar: paykunpay/yashoka/com/paykunpay_lib/PaykunApiCall.java <==
package paykunpay.yashoka.com.paykunpay_lib;

import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.net.http.SslError;
import android.support.annotation.NonNull;
import android.util.Log;
import android.webkit.SslErrorHandler;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.VolleyLog;
import com.android.volley.toolbox.JsonObjectRequest;
import com.thefinestartist.Base;
import com.thefinestartist.utils.content.Ctx;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.Serializable;

import static paykunpay.yashoka.com.paykunpay_lib.AppController.TAG;


public class PaykunApiCall {

    private String urlJsonObj = "https://checkout.paykun.com/test/order/create";
    private ProgressDialog pDialog;
    InterfaceCallback interfaceCallback;
    public PaykunApiCall(InterfaceCallback callback) {
        interfaceCallback = callback;
    }
    public static class Builder implements Serializable {
        protected final transient Context context;
        public Builder(@NonNull Activity activity) {
            this.context = activity;
            Base.initialize(activity);
        }
        protected void show() {
            Intent intent = new Intent(context, PaykunPaymentActivity.class);
            Ctx.startActivity(intent);

        }
        public void show(@NonNull String url) {
            show();
        }
    }
    public  void callApi(Activity activity, String name, String phone){
        Log.e(""," value from project : "+name+" : "+phone);
        //Intent i = new Intent(activity,MainActivity.class);
        //pDialog = new ProgressDialog(activity);
        //pDialog.setMessage("Please wait...");
        //pDialog.setCancelable(false);

        //makeJsonObjectRequest(activity);


    }
    private void makeJsonObjectRequest(final Activity activity) {
        showpDialog();
        JSONObject object = new JSONObject();
        try {
            object.put("merchant_id","201805020001");
            object.put("access_token","asdjfjsdaklfsajf");
            object.put("customer_name","Prashant");
            object.put("customer_email","kambadprashant@gmail.com");
            object.put("customer_phone","9974740564");
            object.put("product_name","Yasoka Product");
            object.put("order_no","789581254");
            object.put("amount","20");
            object.put("device_id","device_id");
            object.put("imei_no","1235644897645");

            object.put("package_name","com.tesdc.test");
            object.put("device_token","aasdfjlkasdfjalksrioewrjlkdsjflsdajf");
            object.put("client_ip","127.0.0.1");
            object.put("os_name","android");
            object.put("os_version","8");

            object.put("timestamp","1552545854");
            object.put("signature","alksdjflasdjflkjasjhasjkasdgfkjashkhjsadhfjsdjfnjsjerhiuisufwrieigbakbbbakjghsdkfhjsddfkasdjffbaskjdfbfdsk");
        } catch (JSONException e) {
            e.printStackTrace();
        }
        JsonObjectRequest jsonObjReq = new JsonObjectRequest(Request.Method.POST,
                urlJsonObj, object, new Response.Listener<JSONObject>() {

            @Override
            public void onResponse(JSONObject response) {
                Log.e(" response : ", response.toString());
                String token ;
                String orderUrl = "";
                try {
                    token = response.getString("_token");
                    orderUrl = response.getString("order_url");
                    
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                WebView webView = new WebView(activity);
                webView.getSettings().setJavaScriptEnabled(true);
                //webView.getSettings().setLoadWithOverviewMode(true);
                //webView.getSettings().setUseWideViewPort(true);
                /*webView.setWebViewClient(new WebViewClient(){

                    @Override
                    public boolean shouldOverrideUrlLoading(WebView view, String url) {
                        //progDailog.show();
                        view.loadUrl(url);

                        return true;
                    }
                    @Override
                    public void onPageFinished(WebView view, final String url) {
                        //progDailog.dismiss();
                    }
                });*/

                webView.loadUrl("http://www.teluguoneradio.com/rssHostDescr.php?hostId=147");
                hidepDialog();
            }
        }, new Response.ErrorListener() {

            @Override
            public void onErrorResponse(VolleyError error) {
                VolleyLog.d(TAG, "Error: " + error.getMessage());
                Toast.makeText(activity,
                        error.getMessage(), Toast.LENGTH_SHORT).show();
                // hide the progress dialog
                hidepDialog();
            }
        });

        // Adding request to request queue
        AppController.getInstance().addToRequestQueue(jsonObjReq);
    }
    private void showpDialog() {
        if (!pDialog.isShowing())
            pDialog.show();
    }

    private void hidepDialog() {
        if (pDialog.isShowing())
            pDialog.dismiss();
    }
}
